summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lib/myconfig.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/myconfig.py b/lib/myconfig.py
index c8f9129..761aecd 100644
--- a/lib/myconfig.py
+++ b/lib/myconfig.py
@@ -128,7 +128,7 @@ class MyConfig:
return " "
def getMaximumCombineNumber(self):
- N = 5
+ N = 7
assert N >= 2, 'at least bi-gram'
return N
@@ -142,10 +142,10 @@ class MyConfig:
return 9 # minimum word occurrence in n-gram table
def getPartialWordThreshold(self):
- return 0.10 # the first 10% in position
+ return 0.70 # the first 70% in position
def getNewWordThreshold(self):
- return 0.95 # the first 95% in position, subject verb object.
+ return 0.70 # the first 70% in position, subject verb object.
def getMinimumEntropy(self):
return 0.01